@@ -83,7 +83,7 @@ void BookWidget::openURL(const KURL & url)
 	m_stream.reset(new TQTextStream(&m_file));
 	m_textLines.reset(new TQStringList);
 	TQString name(encoding());
-	TQTextCodec *codec = TQTextCodec::codecForName(encoding()); // get the codec
+	TQTextCodec *codec = TQTextCodec::codecForName(encoding().latin1()); // get the codec
 	if (codec)
  		m_stream->setCodec(codec);
 	//show progress dialog
